function [y_h]=kpep(c,a,b,alpha,beta,N)
%% Kétpontos peremérték-feladat megoldása
%
%     u''(t)+cu(t)=f(t) c\in\mathbb{R}, f(t)\inC[a,b]
%     u(a)=\alpha u(b)=\beta
%

%% Bemenõ paramatérek listája:

%     c    megadott konstans érték
%     a    intervallum kezdete
%     b    intervallum vége
%     N    intervallumok száma


%% Elõkészületek

% Lépésköz

h=(b-a)/N; 

% A diszkretizáló mátrix összerakása

e=ones(N-1,1);
A_h=(1/h^2)*spdiags([e (-2+h^2*c)*e e],-1:1,N-1,N-1)
%% A numerikus megoldás meghatározása

b_h=ones(N-1,1);
b_h(1)=f(a+h)-alpha*(1/h^2);
b_h(N-1)=f(a+(N-1)*h)-beta*(1/h^2);
for i=2:N-2 
    b_h(i)=f(a+i*h);
end
b_h
y=A_h\b_h;
y_i=linspace(alpha,beta,N+1);
y_i(2:N)=y;
y_h=y_i';


x_i=a:h:b;
plot(x_i,y_i,'r+')

%% Az eredeti feladat jobboldala 
function ered=f(t)
ered=-10*t;



